/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer.jxmap;

import nl.cloudfarming.client.geoviewer.jxmap.map.RootMapPanelController;
import java.awt.BorderLayout;
import java.util.logging.Logger;
import javax.swing.JPanel;
import org.openide.util.NbBundle;
import org.openide.windows.TopComponent;
import org.openide.windows.WindowManager;
import org.netbeans.api.settings.ConvertAsProperties;
import org.openide.explorer.ExplorerManager;
import org.openide.explorer.ExplorerUtils;
import org.openide.util.Lookup;

/**
 * Top component which displays something.
 */
@ConvertAsProperties(dtd = "-//nl.cloudfarming.client.geoviewer.jxmap//MapViewerTopComponent//EN", autostore = false)
public final class MapViewerTopComponent extends TopComponent implements ExplorerManager.Provider, Lookup.Provider {

    private static MapViewerTopComponent instance;
    /** path to the icon used by the component and its open action */
//    static final String ICON_PATH = "SET/PATH/TO/ICON/HERE";
    private static final String PREFERRED_ID = "MapViewerTopComponent";
    private final RootMapPanelController controller = new RootMapPanelController();

    public MapViewerTopComponent() {
        initComponents();
        setName(NbBundle.getMessage(MapViewerTopComponent.class, "CTL_MapViewerTopComponent"));
        setToolTipText(NbBundle.getMessage(MapViewerTopComponent.class, "HINT_MapViewerTopComponent"));

        associateLookup(controller.getLookup());
//        setIcon(ImageUtilities.loadImage(ICON_PATH, true));
    }

    public RootMapPanelController getController() {
        return this.controller;
    }

    /** This method is called from within the constructor to
     * initialize the form.
     */
    private void initComponents() {

        setLayout(new BorderLayout());
        jLayeredPane1 = controller.getPanel();
        add(jLayeredPane1, BorderLayout.CENTER);

    }
    private JPanel jLayeredPane1;

    /**
     * Gets default instance. Do not use directly: reserved for *.settings files only,
     * i.e. deserialization routines; otherwise you could get a non-deserialized instance.
     * To obtain the singleton instance, use {@link #findInstance}.
     */
    public static synchronized MapViewerTopComponent getDefault() {
        if (instance == null) {
            instance = new MapViewerTopComponent();
        }
        return instance;
    }

    /**
     * Obtain the TestWindowTopComponent instance. Never call {@link #getDefault} directly!
     */
    public static synchronized MapViewerTopComponent findInstance() {
        TopComponent win = WindowManager.getDefault().findTopComponent(PREFERRED_ID);
        if (win == null) {
            Logger.getLogger(MapViewerTopComponent.class.getName()).warning(
                    "Cannot find " + PREFERRED_ID + " component. It will not be located properly in the window system.");
            return getDefault();
        }
        if (win instanceof MapViewerTopComponent) {
            return (MapViewerTopComponent) win;
        }
        Logger.getLogger(MapViewerTopComponent.class.getName()).warning(
                "There seem to be multiple components with the '" + PREFERRED_ID
                + "' ID. That is a potential source of errors and unexpected behavior.");
        return getDefault();
    }

    @Override
    public int getPersistenceType() {
        return TopComponent.PERSISTENCE_ALWAYS;
    }

    @Override
    public void componentOpened() {
        // TODO add custom code on component opening
    }

    @Override
    public void componentClosed() {
        // TODO add custom code on component closing
    }

    void writeProperties(java.util.Properties p) {
        // better to version settings since initial version as advocated at
        // http://wiki.apidesign.org/wiki/PropertyFiles
        p.setProperty("version", "1.0");
        // TODO store your settings
    }

    Object readProperties(java.util.Properties p) {
        if (instance == null) {
            instance = this;
        }
        instance.readPropertiesImpl(p);
        return instance;
    }

    private void readPropertiesImpl(java.util.Properties p) {
        String version = p.getProperty("version");
        // TODO read your settings according to their version
    }

    @Override
    protected String preferredID() {
        return PREFERRED_ID;
    }

    @Override
    public void addNotify() {
        super.addNotify();
        controller.setActive(true);
    }

    @Override
    public void removeNotify() {
        super.removeNotify();
        controller.setActive(false);
    }

    @Override
    public ExplorerManager getExplorerManager() {
        return controller.getExplorerManager();
    }
    // It is good idea to switch all listeners on and off when the
    // component is shown or hidden. In the case of TopComponent use:

    @Override
    protected void componentActivated() {
        ExplorerUtils.activateActions(controller.getExplorerManager(), true);
    }

    @Override
    protected void componentDeactivated() {
        ExplorerUtils.activateActions(controller.getExplorerManager(), false);
    }


}
