/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer.jxmap.map;

import java.awt.AlphaComposite;
import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Font;
import java.awt.Graphics2D;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.RenderingHints;
import java.awt.geom.Point2D;
import org.jdesktop.swingx.JXMapViewer;
import org.jdesktop.swingx.mapviewer.GeoPosition;
import org.netbeans.api.visual.widget.Scene;
import org.netbeans.api.visual.widget.Widget;

/**
 *
 * @author Timon Veenstra
 */
public class PointWidget extends Widget {

    private Font font = new Font("Dialog", Font.BOLD, 12);
    private double alpha = (100 - (double) 0 /*transparancy*/) / 100;
    private static int STROKE_WIDTH = 2; // stroke of the rectangle surrounding the label (pixels)
    private final JXMapViewer mapViewer;
    private final GeoPosition position;

    public PointWidget(Scene scene, JXMapViewer mapViewer, GeoPosition position) {
        super(scene);
        this.mapViewer = mapViewer;
        this.position = position;

//        setPreferredSize(new Dimension(ICON_SIZE, ICON_SIZE));
//
//        final Point2D pointOnMap = mapViewer.getTileFactory().geoToPixel(position, mapViewer.getZoom());
//        Rectangle viewportBounds = mapViewer.getViewportBounds();
//        int x = (int) (pointOnMap.getX() - viewportBounds.getX());
//        int y = (int) (pointOnMap.getY() - viewportBounds.getY());
//        setPreferredLocation(new java.awt.Point(x, y));
        setForeground(Color.red);
    }

    @Override
    protected void paintWidget() {
        Graphics2D g = getGraphics();

        final Point2D pointOnMap = mapViewer.getTileFactory().geoToPixel(position, mapViewer.getZoom());

        Rectangle viewportBounds = mapViewer.getViewportBounds();

        if (viewportBounds.contains(pointOnMap)) {
            final int x = (int) (pointOnMap.getX() - viewportBounds.getX());
            final int y = (int) (pointOnMap.getY() - viewportBounds.getY());

            g.setFont(font);
            g.setColor(Color.red);
            g.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER, new Float(alpha)));
            g.setRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING, RenderingHints.VALUE_TEXT_ANTIALIAS_ON);
            g.setStroke(new BasicStroke(STROKE_WIDTH, BasicStroke.CAP_ROUND, BasicStroke.JOIN_ROUND));

            int size = 20 - (this.mapViewer.getZoom() * 2);
            size = (size < 0) ? 0 : size;

            if (size > 0) {
                Rectangle rect = new Rectangle(size, size, size, size);
                rect.setLocation(x - (size / 2), y - (size / 2));
                g.draw(rect);
                g.drawRect(x - (STROKE_WIDTH / 2), y - (STROKE_WIDTH / 2), STROKE_WIDTH, STROKE_WIDTH);
            }
        }

    }
}
